==> mingw-w64-clang-aarch64-flecs-docs-3.2.12-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/group__misc__types.js <==
var group__misc__types =
[
    [ "ecs_value_t", "structecs__value__t.html", null ],
    [ "ecs_build_info_t", "structecs__build__info__t.html", [
      [ "addons", "structecs__build__info__t.html#a7470b69cc140c386908ec8102cfc6e8f", null ],
      [ "compiler", "structecs__build__info__t.html#a8162a3130dd6c6b769e8da3451700d28", null ],
      [ "debug", "structecs__build__info__t.html#af2735a6a8d0994173a3bbcf9b4e1ee9e", null ],
      [ "perf_trace", "structecs__build__info__t.html#ac3673cab868e24d52cd699916424dd32", null ],
      [ "sanitize", "structecs__build__info__t.html#aa21677164909e9e5e70f835b9337f18d", null ],
      [ "version", "structecs__build__info__t.html#a7a4ad256819c542324f4a0b0248a2987", null ],
      [ "version_major", "structecs__build__info__t.html#a4c312478e6bcbfbbbeff0ba86f645cc0", null ],
      [ "version_minor", "structecs__build__info__t.html#ad58e1e2bd9fc9c3a792c32876ddd7ac6", null ],
      [ "version_patch", "structecs__build__info__t.html#afa6859e83affe8784fe304ccf4b44463", null ]
    ] ],
    [ "ecs_world_info_t", "structecs__world__info__t.html", [
      [ "add_count", "structecs__world__info__t.html#afe0e60a00cc6a86fd9a43a939682401c", null ],
      [ "batched_command_count", "structecs__world__info__t.html#aaef75ee066e7ac07d87e3981691a1914", null ],
      [ "batched_entity_count", "structecs__world__info__t.html#ac5f59a01986840e4f50f3da781ad972e", null ],
      [ "clear_count", "structecs__world__info__t.html#a95a15d721f0097f4138905745d57b479", null ],
      [ "component_id_count", "structecs__world__info__t.html#a378acee81e415d7be9749ab13a73af05", null ],
      [ "delete_count", "structecs__world__info__t.html#abda93bc5d7bb20903380851b79ac4ea2", null ],
      [ "delta_time", "structecs__world__info__t.html#a064a745a142d7865c93895fafaa57891", null ],
      [ "delta_time_raw", "structecs__world__info__t.html#a423da320e10ad87b102a25bd74368ed0", null ],
      [ "discard_count", "structecs__world__info__t.html#a8903bd78dec7d3e3587449550ce78757", null ],
      [ "emit_time_total", "structecs__world__info__t.html#addc95155d813cdbe161453deb8404439", null ],
      [ "empty_table_count", "structecs__world__info__t.html#a96932bc58af61e454e2b3adaf86bb1b9", null ],
      [ "ensure_count", "structecs__world__info__t.html#ad020d3b27b217d172c0c64c7e4e3f1d9", null ],
      [ "event_count", "structecs__world__info__t.html#afd1bb68fe49013ad76047e64592f8100", null ],
      [ "frame_count_total", "structecs__world__info__t.html#aa4c02d4fe25be5db38562857bdd989c0", null ],
      [ "frame_time_total", "structecs__world__info__t.html#a476cbcb4156a37a512dcc76c6eed97c0", null ],
      [ "id_create_total", "structecs__world__info__t.html#abff0b796f60b04b1c07125725f2da679", null ],
      [ "id_delete_total", "structecs__world__info__t.html#a7137546174c7ecb2ab211d2bbeedb07b", null ],
      [ "last_component_id", "structecs__world__info__t.html#a9602a1615e0a6f2c7c9ecc815026cdbe", null ],
      [ "max_id", "structecs__world__info__t.html#aa6ad73c201fbb7e95b242a7e47ce5455", null ],
      [ "merge_count_total", "structecs__world__info__t.html#aa9a9268a94b6a8c5f337b309f60e44b4", null ],
      [ "merge_time_total", "structecs__world__info__t.html#a7d5bf7bb6257b5e25c415e9982f116cf", null ],
      [ "min_id", "structecs__world__info__t.html#a0a65987b62c3178691a01b471b8f7645", null ],
      [ "modified_count", "structecs__world__info__t.html#aedfc548cb8fc79b8754e6814a3c22bae", null ],
      [ "name_prefix", "structecs__world__info__t.html#af13ccc527262482ab8b3c9edb64d8431", null ],
      [ "observers_ran_frame", "structecs__world__info__t.html#a6b293969d1ea425bd7a4347ba5b4bcdc", null ],
      [ "other_count", "structecs__world__info__t.html#aab783a62bb921e69029de256f3c67d96", null ],
      [ "pair_id_count", "structecs__world__info__t.html#acd8c02366b31f72d77b26e8c6c971aa0", null ],
      [ "pipeline_build_count_total", "structecs__world__info__t.html#a402efe5be309f8c0aa544f5e1b4f3caf", null ],
      [ "rematch_count_total", "structecs__world__info__t.html#abeff90c0e8f3aeab0e7239e58dae0edc", null ],
      [ "rematch_time_total", "structecs__world__info__t.html#ad00bc59ae9524dab4b717254cb122063", null ],
      [ "remove_count", "structecs__world__info__t.html#affad76fae2aaf5e94d51fc41b73e80f1", null ],
      [ "set_count", "structecs__world__info__t.html#a199919dd6a4c1f72a210b34f2babc7f8", null ],
      [ "system_time_total", "structecs__world__info__t.html#a709766143fc7b96eeb173581ab535115", null ],
      [ "systems_ran_frame", "structecs__world__info__t.html#a74abc83acdc8b3dab7cde29f40bb354b", null ],
      [ "table_count", "structecs__world__info__t.html#a40cbca3ca9140b44cb0f8f15b648bb54", null ],
      [ "table_create_total", "structecs__world__info__t.html#a69a67fda146fcd79f23232f07a32f443", null ],
      [ "table_delete_total", "structecs__world__info__t.html#ab3807b0f99e15a5b51f0fe005faef828", null ],
      [ "tag_id_count", "structecs__world__info__t.html#a2901c410da4cec94cb906047e3373c16", null ],
      [ "target_fps", "structecs__world__info__t.html#ad059d897fe88116cb0450903d0bd7867", null ],
      [ "time_scale", "structecs__world__info__t.html#ac88b4bbcfb1c4101531265844f1efaea", null ],
      [ "world_time_total", "structecs__world__info__t.html#a24a460522862ab2998fa009b76a8422e", null ],
      [ "world_time_total_raw", "structecs__world__info__t.html#a567f916eee13a76f464c3d9fc5d54dd9", null ]
    ] ],
    [ "ecs_query_group_info_t", "structecs__query__group__info__t.html", [
      [ "ctx", "structecs__query__group__info__t.html#a3af076cfbbc62d4521edfbcc8e2611b1", null ],
      [ "match_count", "structecs__query__group__info__t.html#a81331329cc77bd18afa7e62f66c85dd8", null ],
      [ "table_count", "structecs__query__group__info__t.html#a0489e7117e39ce91555db90dbf2e97dc", null ]
    ] ],
    [ "ecs_build_info_t", "group__misc__types.html#gaf2c4812d83cfee1027709de8c761b844", null ],
    [ "ecs_query_group_info_t", "group__misc__types.html#ga6775756254018e33b5ae1f6c75717a85", null ],
    [ "ecs_world_info_t", "group__misc__types.html#ga06025899fe47f33d152d10f0c69c3a8e", null ]
];

==> mingw-w64-clang-aarch64-flecs-docs-4.0.5-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/group__misc__types.js <==
var group__misc__types =
[
    [ "ecs_build_info_t", "structecs__build__info__t.html", [
      [ "addons", "structecs__build__info__t.html#a7470b69cc140c386908ec8102cfc6e8f", null ],
      [ "compiler", "structecs__build__info__t.html#a8162a3130dd6c6b769e8da3451700d28", null ],
      [ "debug", "structecs__build__info__t.html#af2735a6a8d0994173a3bbcf9b4e1ee9e", null ],
      [ "perf_trace", "structecs__build__info__t.html#ac3673cab868e24d52cd699916424dd32", null ],
      [ "sanitize", "structecs__build__info__t.html#aa21677164909e9e5e70f835b9337f18d", null ],
      [ "version", "structecs__build__info__t.html#a7a4ad256819c542324f4a0b0248a2987", null ],
      [ "version_major", "structecs__build__info__t.html#a4c312478e6bcbfbbbeff0ba86f645cc0", null ],
      [ "version_minor", "structecs__build__info__t.html#ad58e1e2bd9fc9c3a792c32876ddd7ac6", null ],
      [ "version_patch", "structecs__build__info__t.html#afa6859e83affe8784fe304ccf4b44463", null ]
    ] ],
    [ "ecs_world_info_t", "structecs__world__info__t.html", [
      [ "add_count", "structecs__world__info__t.html#afe0e60a00cc6a86fd9a43a939682401c", null ],
      [ "batched_command_count", "structecs__world__info__t.html#aaef75ee066e7ac07d87e3981691a1914", null ],
      [ "batched_entity_count", "structecs__world__info__t.html#ac5f59a01986840e4f50f3da781ad972e", null ],
      [ "clear_count", "structecs__world__info__t.html#a95a15d721f0097f4138905745d57b479", null ],
      [ "cmd", "structecs__world__info__t.html#a764899dca86a9bd5ecac6a01aa89463b", null ],
      [ "component_id_count", "structecs__world__info__t.html#a378acee81e415d7be9749ab13a73af05", null ],
      [ "delete_count", "structecs__world__info__t.html#abda93bc5d7bb20903380851b79ac4ea2", null ],
      [ "delta_time", "structecs__world__info__t.html#a064a745a142d7865c93895fafaa57891", null ],
      [ "delta_time_raw", "structecs__world__info__t.html#a423da320e10ad87b102a25bd74368ed0", null ],
      [ "discard_count", "structecs__world__info__t.html#a8903bd78dec7d3e3587449550ce78757", null ],
      [ "emit_time_total", "structecs__world__info__t.html#addc95155d813cdbe161453deb8404439", null ],
      [ "ensure_count", "structecs__world__info__t.html#ad020d3b27b217d172c0c64c7e4e3f1d9", null ],
      [ "eval_comp_monitors_total", "structecs__world__info__t.html#a4064930117e1990faf03594094545ee6", null ],
      [ "event_count", "structecs__world__info__t.html#afd1bb68fe49013ad76047e64592f8100", null ],
      [ "frame_count_total", "structecs__world__info__t.html#aa4c02d4fe25be5db38562857bdd989c0", null ],
      [ "frame_time_total", "structecs__world__info__t.html#a476cbcb4156a37a512dcc76c6eed97c0", null ],
      [ "id_create_total", "structecs__world__info__t.html#abff0b796f60b04b1c07125725f2da679", null ],
      [ "id_delete_total", "structecs__world__info__t.html#a7137546174c7ecb2ab211d2bbeedb07b", null ],
      [ "last_component_id", "structecs__world__info__t.html#a9602a1615e0a6f2c7c9ecc815026cdbe", null ],
      [ "max_id", "structecs__world__info__t.html#aa6ad73c201fbb7e95b242a7e47ce5455", null ],
      [ "merge_count_total", "structecs__world__info__t.html#aa9a9268a94b6a8c5f337b309f60e44b4", null ],
      [ "merge_time_total", "structecs__world__info__t.html#a7d5bf7bb6257b5e25c415e9982f116cf", null ],
      [ "min_id", "structecs__world__info__t.html#a0a65987b62c3178691a01b471b8f7645", null ],
      [ "modified_count", "structecs__world__info__t.html#aedfc548cb8fc79b8754e6814a3c22bae", null ],
      [ "name_prefix", "structecs__world__info__t.html#af13ccc527262482ab8b3c9edb64d8431", null ],
      [ "observers_ran_frame", "structecs__world__info__t.html#a6b293969d1ea425bd7a4347ba5b4bcdc", null ],
      [ "other_count", "structecs__world__info__t.html#aab783a62bb921e69029de256f3c67d96", null ],
      [ "pair_id_count", "structecs__world__info__t.html#acd8c02366b31f72d77b26e8c6c971aa0", null ],
      [ "pipeline_build_count_total", "structecs__world__info__t.html#a402efe5be309f8c0aa544f5e1b4f3caf", null ],
      [ "rematch_count_total", "structecs__world__info__t.html#abeff90c0e8f3aeab0e7239e58dae0edc", null ],
      [ "rematch_time_total", "structecs__world__info__t.html#ad00bc59ae9524dab4b717254cb122063", null ],
      [ "remove_count", "structecs__world__info__t.html#affad76fae2aaf5e94d51fc41b73e80f1", null ],
      [ "set_count", "structecs__world__info__t.html#a199919dd6a4c1f72a210b34f2babc7f8", null ],
      [ "system_time_total", "structecs__world__info__t.html#a709766143fc7b96eeb173581ab535115", null ],
      [ "systems_ran_frame", "structecs__world__info__t.html#a74abc83acdc8b3dab7cde29f40bb354b", null ],
      [ "table_count", "structecs__world__info__t.html#a40cbca3ca9140b44cb0f8f15b648bb54", null ],
      [ "table_create_total", "structecs__world__info__t.html#a69a67fda146fcd79f23232f07a32f443", null ],
      [ "table_delete_total", "structecs__world__info__t.html#ab3807b0f99e15a5b51f0fe005faef828", null ],
      [ "tag_id_count", "structecs__world__info__t.html#a2901c410da4cec94cb906047e3373c16", null ],
      [ "target_fps", "structecs__world__info__t.html#ad059d897fe88116cb0450903d0bd7867", null ],
      [ "time_scale", "structecs__world__info__t.html#ac88b4bbcfb1c4101531265844f1efaea", null ],
      [ "world_time_total", "structecs__world__info__t.html#a1f7e9758f03d588621b5e6bf8b39d14c", null ],
      [ "world_time_total_raw", "structecs__world__info__t.html#ad8e510cda71b25a716b2230b9b534f83", null ]
    ] ],
    [ "ecs_query_group_info_t", "structecs__query__group__info__t.html", [
      [ "ctx", "structecs__query__group__info__t.html#a3af076cfbbc62d4521edfbcc8e2611b1", null ],
      [ "match_count", "structecs__query__group__info__t.html#a81331329cc77bd18afa7e62f66c85dd8", null ],
      [ "table_count", "structecs__query__group__info__t.html#a0489e7117e39ce91555db90dbf2e97dc", null ]
    ] ],
    [ "ecs_build_info_t", "group__misc__types.html#gaf2c4812d83cfee1027709de8c761b844", null ],
    [ "ecs_query_group_info_t", "group__misc__types.html#ga6775756254018e33b5ae1f6c75717a85", null ],
    [ "ecs_world_info_t", "group__misc__types.html#ga06025899fe47f33d152d10f0c69c3a8e", null ]
];
